# Tutorials

Below you will find hands-on notebooks demonstrating typical `grassp` workflows.

```{toctree}
:maxdepth: 1

notebooks/DC_tutorial
notebooks/OrgIP_tutorial
notebooks/integration_tutorial
```
